# InvestigationPlaybookTask

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**arguments** | **dict(str, object)** |  | [optional] 
**assignee** | **str** |  | [optional] 
**assignee_set** | **bool** |  | [optional] 
**blocking_tasks** | **list[str]** |  | [optional] 
**comments** | **bool** | Whether this task had any comments or not | [optional] 
**completed_by** | **str** |  | [optional] 
**completed_count** | **int** |  | [optional] 
**completed_date** | **datetime** |  | [optional] 
**conditions** | [**list[TaskCondition]**](TaskCondition.md) | Conditions - optional list of conditions to run when task is conditional. we check conditions by their order (e.i. - considering the first one that satisfied) | [optional] 
**continue_on_error** | **bool** |  | [optional] 
**default_assignee** | **str** |  | [optional] 
**default_assignee_complex** | [**AdvanceArg**](AdvanceArg.md) |  | [optional] 
**default_reminder** | **int** |  | [optional] 
**due_date** | **datetime** |  | [optional] 
**due_date_set** | **bool** |  | [optional] 
**entries** | **list[str]** |  | [optional] 
**evidence_data** | [**EvidenceData**](EvidenceData.md) |  | [optional] 
**execution_count** | **int** |  | [optional] 
**field_mapping** | [**list[FieldMapping]**](FieldMapping.md) |  | [optional] 
**for_each_index** | **int** | Parameters needed for loops | [optional] 
**for_each_inputs** | **dict(str, list[object])** |  | [optional] 
**form** | [**DataCollectionForm**](DataCollectionForm.md) |  | [optional] 
**id** | **str** |  | [optional] 
**ignore_worker** | **bool** | Do not run this task in a worker | [optional] 
**indent** | **int** |  | [optional] 
**input** | **str** |  | [optional] 
**loop** | [**TaskLoop**](TaskLoop.md) |  | [optional] 
**message** | [**NotifiableItem**](NotifiableItem.md) |  | [optional] 
**next_tasks** | **dict(str, list[str])** |  | [optional] 
**note** | **bool** |  | [optional] 
**outputs** | **dict(str, object)** |  | [optional] 
**parent_block_count** | **int** | the number of tasks that are waiting on blocked in subplaybooks of this task | [optional] 
**parent_playbook_id** | **str** |  | [optional] 
**patched** | **bool** | Indicates whether this task was patched to InvPB and did not originally belong to the playbook | [optional] 
**playbook_inputs** | **dict(str, object)** |  | [optional] 
**previous_tasks** | **dict(str, list[str])** |  | [optional] 
**quiet_mode** | [**QuietMode**](QuietMode.md) |  | [optional] 
**reminder** | **int** | Duration in minutes, this field is not persisted here | [optional] 
**reputation_calc** | [**ReputationCalcAlg**](ReputationCalcAlg.md) |  | [optional] 
**restricted_completion** | **bool** |  | [optional] 
**script_arguments** | [**dict(str, AdvanceArg)**](AdvanceArg.md) |  | [optional] 
**separate_context** | **bool** |  | [optional] 
**sla** | [**SLA**](SLA.md) |  | [optional] 
**sla_reminder** | [**SLA**](SLA.md) |  | [optional] 
**start_date** | **datetime** |  | [optional] 
**state** | [**TaskState**](TaskState.md) |  | [optional] 
**sub_playbook** | [**InvestigationPlaybook**](InvestigationPlaybook.md) |  | [optional] 
**task** | [**Task**](Task.md) |  | [optional] 
**task_complete_data** | [**list[InvPlaybookTaskCompleteData]**](InvPlaybookTaskCompleteData.md) | History complete data | [optional] 
**task_id** | **str** |  | [optional] 
**timer_triggers** | [**list[TimerTrigger]**](TimerTrigger.md) | SLA fields | [optional] 
**type** | [**TaskType**](TaskType.md) |  | [optional] 
**view** | [**TaskView**](TaskView.md) |  | [optional] 
**will_not_execute_count** | **int** |  | [optional] 

[[Back to Model list]](README.md#documentation-for-models) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to README]](README.md)


